configuration_service library

Enables applications to make effective use of JSON configuration files. Especially useful for backend services or CLI tools written in Dart but can also be used with Flutter.

Classes

ConfigurationService
Derive from this class to create a configuration service. Add any values as properties of this class using ConfigurationValue. Register all values in the constructor with register to ensure they are picked up when loading the configuration file.
ConfigurationValue<T>
Stores a configuration value that can be read from or written to a configuration file.
Optional<T>
Defines an optional value. An optional value can distinguish between whether a value has been assigned (isSet) or not. Construct an optional that has a value by using the unnamed constructor, such as Optional<int>(10). An optional without value can be created by using Optional.none()